@@ -12,15 +12,6 @@ __status__ = 'Development'
 __credits__ = 'Yohan Alexander'
 __docs__ = 'https://z2n-periodogram.readthedocs.io'
 __url__ = 'https://github.com/yohanalexander/z2n-periodogram'
-__z2n__ = '''
-        Z2n Software, a program for interactive periodograms analysis.
-        Copyright (C) 2020, and MIT License, by Yohan Alexander [UFS].
-        Type "help" for more information or "docs" for documentation.
-        '''
-__plt__ = '''
-        Interactive plotting window of the Z2n Software.
-        Type "help" for more information.
-        '''
 
 try:
     __version__ = get_distribution(__project__).version
